Introduction
============

A library to easily measure what's going on in your python.

Metrology allows you to add instruments to your python code and hook them to external reporting tools like Graphite so as to better understand what's going on in your running python program.

You can report bugs and discuss features on the `issues page <https://github.com/cyberdelia/metrology/issues>`_.

Table Of Contents
=================

.. toctree::
   :maxdepth: 2

   installation
   instruments
   reporters

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`